@@ -3,7 +3,7 @@ from typing import Optional
 
 import click
 
-from lhotse import FeatureSet, Features, LilcomURLWriter, Seconds
+from lhotse import Features, FeatureSet, LilcomURLWriter, Seconds
 from lhotse.audio import RecordingSet
 from lhotse.bin.modes.cli_base import cli
 from lhotse.features import (
@@ -257,6 +257,7 @@ def upload(
     and assumes that you have the write permissions.
     """
     from concurrent.futures import ProcessPoolExecutor
+
     from tqdm import tqdm
 
     output_manifest = Path(output_manifest)
@@ -277,9 +278,9 @@ def upload(
 
 
 def _upload_one(item: Features, url: str) -> Features:
-    feats_mtx = item.load()
+    feats_mat = item.load()
     feats_writer = LilcomURLWriter(url)
-    new_key = feats_writer.write(key=item.storage_key, value=feats_mtx)
+    new_key = feats_writer.write(key=item.storage_key, value=feats_mat)
     return fastcopy(
         item, storage_path=url, storage_key=new_key, storage_type=feats_writer.name
     )
