@@ -683,6 +683,7 @@ class ChunkedLilcomHdf5Writer(FeaturesWriter):
 
     def write(self, key: str, value: np.ndarray) -> str:
         import h5py
+
         from lhotse.features.compression import lilcom_compress_chunked
 
         serialized_feats = lilcom_compress_chunked(
@@ -824,7 +825,7 @@ class LilcomChunkyWriter(FeaturesWriter):
 
         if "b" not in mode:
             mode = mode + "b"
-        assert mode == "wb" or "ab"
+        assert mode in ("wb", "ab")
 
         # ".lca" -> "lilcom chunky archive"
         self.storage_path_ = Path(storage_path).with_suffix(".lca")
