@@ -13,10 +13,17 @@ confirmed by Jesus.
 
 This implementation works well with autograd and batching, and can be used neural network
 layers.
+
+Update January 2022:
+These modules now expose a new API function called "online_inference" that
+may be used to compute the features when the audio is streaming.
+The implementation is stateless, and passes the waveform remainders
+back to the user to feed them to the modules once new data becomes available.
+The implementation is compatible with JIT scripting via TorchScript.
 """
 import math
 import warnings
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Tuple
 
 import numpy as np
 import torch
@@ -34,7 +41,6 @@ try:
     def _spectrogram(x: torch.Tensor) -> torch.Tensor:
         return x.abs()
 
-
 except ImportError:
 
     def _rfft(x: torch.Tensor) -> torch.Tensor:
@@ -94,6 +100,7 @@ class Wav2Win(nn.Module):
         self.preemph_coeff = preemph_coeff
         self.window_type = window_type
         self.dither = dither
+        # torchscript expects it to be a tensor
         self.snip_edges = snip_edges
         self.energy_floor = energy_floor
         self.raw_energy = raw_energy
@@ -141,33 +148,23 @@ class Wav2Win(nn.Module):
         )
         return s
 
-    def forward(
-        self, x: torch.Tensor
-    ) -> Union[torch.Tensor, Tuple[torch.Tensor, torch.Tensor]]:
-        # Add dither
-        if self.dither != 0.0:
-            n = torch.randn(x.shape, device=x.device)
-            x = x + self.dither * n
-
+    def _forward_strided(
+        self, x_strided: torch.Tensor
+    ) -> Tuple[torch.Tensor, Optional[torch.Tensor]]:
         # remove offset
         if self.remove_dc_offset:
-            mu = torch.mean(x, dim=1, keepdim=True)
-            x = x - mu
+            mu = torch.mean(x_strided, dim=2, keepdim=True)
+            x_strided = x_strided - mu
 
+        # Compute the log energy of each frame
+        log_energy: Optional[torch.Tensor] = None
         if self.return_log_energy and self.raw_energy:
-            # Compute the log energy of each frame
-            x_strided = _get_strided_batch(
-                x, self._length, self._shift, self.snip_edges
-            )
             log_energy = _get_log_energy(x_strided, self.energy_floor)  # size (m)
 
+        # preemphasis
         if self.preemph_coeff != 0.0:
-            x_offset = torch.nn.functional.pad(
-                x.unsqueeze(1), (1, 0), mode="replicate"
-            ).squeeze(1)
-            x = x - self.preemph_coeff * x_offset[:, :-1]
-
-        x_strided = _get_strided_batch(x, self._length, self._shift, self.snip_edges)
+            x_offset = torch.nn.functional.pad(x_strided, (1, 0), mode="replicate")
+            x_strided = x_strided - self.preemph_coeff * x_offset[:, :, :-1]
 
         # Apply window_function to each frame
         x_strided = x_strided * self._window
@@ -176,13 +173,57 @@ class Wav2Win(nn.Module):
         if self.pad_length != self._length:
             pad = self.pad_length - self._length
             x_strided = torch.nn.functional.pad(
-                x_strided.unsqueeze(1), (0, pad), mode="constant", value=0
+                # torchscript expects pad to be list of int
+                x_strided.unsqueeze(1),
+                [0, pad],
+                mode="constant",
+                value=0.0,
             ).squeeze(1)
 
-        if self.return_log_energy:
-            return x_strided, log_energy
+        if self.return_log_energy and not self.raw_energy:
+            # This energy is computed after preemphasis, window, etc.
+            log_energy = _get_log_energy(x_strided, self.energy_floor)  # size (m)
 
-        return x_strided
+        return x_strided, log_energy
+
+    def forward(self, x: torch.Tensor) -> Tuple[torch.Tensor, Optional[torch.Tensor]]:
+        # Add dither
+        if self.dither != 0.0:
+            n = torch.randn(x.shape, device=x.device)
+            x = x + self.dither * n
+
+        x_strided = _get_strided_batch(x, self._length, self._shift, self.snip_edges)
+
+        return self._forward_strided(x_strided)
+
+    @torch.jit.export
+    def online_inference(
+        self, x: torch.Tensor, context: Optional[torch.Tensor] = None
+    ) -> Tuple[Tuple[torch.Tensor, Optional[torch.Tensor]], torch.Tensor]:
+        """
+        The same as the ``forward()`` method, except it accepts an extra argument with the
+        remainder waveform from the previous call of ``online_inference()``, and returns
+        a tuple of ``((frames, log_energy), remainder)``.
+        """
+        assert (
+            not self.snip_edges
+        ), "Unsupported operation: snip_edges == True is not supported for online inference."
+
+        # Add dither
+        if self.dither != 0.0:
+            n = torch.randn(x.shape, device=x.device)
+            x = x + self.dither * n
+
+        x_strided, remainder = _get_strided_batch_streaming(
+            x,
+            window_length=self._length,
+            window_shift=self._shift,
+            prev_remainder=context,
+        )
+
+        x_strided, log_energy = self._forward_strided(x_strided)
+
+        return (x_strided, log_energy), remainder
 
 
 class Wav2FFT(nn.Module):
@@ -210,7 +251,7 @@ class Wav2FFT(nn.Module):
         sampling_rate: int = 16000,
         frame_length: Seconds = 0.025,
         frame_shift: Seconds = 0.01,
-        fft_length: int = 512,
+        round_to_power_of_two: bool = True,
         remove_dc_offset: bool = True,
         preemph_coeff: float = 0.97,
         window_type: str = "povey",
@@ -221,17 +262,14 @@ class Wav2FFT(nn.Module):
         use_energy: bool = True,
     ) -> None:
         super().__init__()
-
+        self.use_energy = use_energy
         N = int(math.floor(frame_length * sampling_rate))
-        if N > fft_length:
-            k = math.ceil(math.log(N) / math.log(2))
-            self.fft_length = int(2 ** k)
-
+        self.fft_length = next_power_of_2(N) if round_to_power_of_two else N
         self.wav2win = Wav2Win(
             sampling_rate,
             frame_length,
             frame_shift,
-            pad_length=fft_length,
+            pad_length=self.fft_length,
             remove_dc_offset=remove_dc_offset,
             preemph_coeff=preemph_coeff,
             window_type=window_type,
@@ -242,9 +280,6 @@ class Wav2FFT(nn.Module):
             return_log_energy=use_energy,
         )
 
-        self.fft_length = fft_length
-        self.use_energy = use_energy
-
     @property
     def sampling_rate(self) -> int:
         return self.wav2win.sampling_rate
@@ -273,18 +308,32 @@ class Wav2FFT(nn.Module):
     def dither(self) -> float:
         return self.wav2win.dither
 
-    def forward(self, x: torch.Tensor) -> torch.Tensor:
-        x_strided = self.wav2win(x)
-        if self.use_energy:
-            x_strided, log_e = x_strided
-
+    def _forward_strided(
+        self, x_strided: torch.Tensor, log_e: Optional[torch.Tensor]
+    ) -> torch.Tensor:
+        # Note: subclasses of this module can override ``_forward_strided()`` and get a working
+        # implementation of ``forward()`` and ``online_inference()`` for free.
         X = _rfft(x_strided)
 
-        if self.use_energy:
+        # log_e is not None is needed by torchscript
+        if self.use_energy and log_e is not None:
             X[:, :, 0] = log_e
 
         return X
 
+    def forward(self, x: torch.Tensor) -> torch.Tensor:
+        x_strided, log_e = self.wav2win(x)
+        return self._forward_strided(x_strided=x_strided, log_e=log_e)
+
+    @torch.jit.export
+    def online_inference(
+        self, x: torch.Tensor, context: Optional[torch.Tensor] = None
+    ) -> Tuple[torch.Tensor, torch.Tensor]:
+        (x_strided, log_e), remainder = self.wav2win.online_inference(
+            x, context=context
+        )
+        return self._forward_strided(x_strided=x_strided, log_e=log_e), remainder
+
 
 class Wav2Spec(Wav2FFT):
     """
@@ -311,7 +360,7 @@ class Wav2Spec(Wav2FFT):
         sampling_rate: int = 16000,
         frame_length: Seconds = 0.025,
         frame_shift: Seconds = 0.01,
-        fft_length: int = 512,
+        round_to_power_of_two: bool = True,
         remove_dc_offset: bool = True,
         preemph_coeff: float = 0.97,
         window_type: str = "povey",
@@ -326,7 +375,7 @@ class Wav2Spec(Wav2FFT):
             sampling_rate,
             frame_length,
             frame_shift,
-            fft_length,
+            round_to_power_of_two=round_to_power_of_two,
             remove_dc_offset=remove_dc_offset,
             preemph_coeff=preemph_coeff,
             window_type=window_type,
@@ -342,15 +391,14 @@ class Wav2Spec(Wav2FFT):
         else:
             self._to_spec = _pow_spectrogram
 
-    def forward(self, x: torch.Tensor) -> torch.Tensor:
-        x_strided = self.wav2win(x)
-        if self.use_energy:
-            x_strided, log_e = x_strided
-
+    def _forward_strided(
+        self, x_strided: torch.Tensor, log_e: Optional[torch.Tensor]
+    ) -> torch.Tensor:
         X = _rfft(x_strided)
         pow_spec = self._to_spec(X)
 
-        if self.use_energy:
+        # log_e is not None is needed by torchscript
+        if self.use_energy and log_e is not None:
             pow_spec[:, :, 0] = log_e
 
         return pow_spec
@@ -381,7 +429,7 @@ class Wav2LogSpec(Wav2FFT):
         sampling_rate: int = 16000,
         frame_length: Seconds = 0.025,
         frame_shift: Seconds = 0.01,
-        fft_length: int = 512,
+        round_to_power_of_two: bool = True,
         remove_dc_offset: bool = True,
         preemph_coeff: float = 0.97,
         window_type: str = "povey",
@@ -396,7 +444,7 @@ class Wav2LogSpec(Wav2FFT):
             sampling_rate,
             frame_length,
             frame_shift,
-            fft_length,
+            round_to_power_of_two=round_to_power_of_two,
             remove_dc_offset=remove_dc_offset,
             preemph_coeff=preemph_coeff,
             window_type=window_type,
@@ -412,17 +460,16 @@ class Wav2LogSpec(Wav2FFT):
         else:
             self._to_spec = _pow_spectrogram
 
-    def forward(self, x: torch.Tensor) -> torch.Tensor:
-        x_strided = self.wav2win(x)
-        if self.use_energy:
-            x_strided, log_e = x_strided
-
+    def _forward_strided(
+        self, x_strided: torch.Tensor, log_e: Optional[torch.Tensor]
+    ) -> torch.Tensor:
         X = _rfft(x_strided)
         pow_spec = self._to_spec(X)
 
         pow_spec = (pow_spec + 1e-15).log()
 
-        if self.use_energy:
+        # log_e is not None is needed by torchscript
+        if self.use_energy and log_e is not None:
             pow_spec[:, :, 0] = log_e
 
         return pow_spec
@@ -451,7 +498,7 @@ class Wav2LogFilterBank(Wav2FFT):
         sampling_rate: int = 16000,
         frame_length: Seconds = 0.025,
         frame_shift: Seconds = 0.01,
-        fft_length: int = 512,
+        round_to_power_of_two: bool = True,
         remove_dc_offset: bool = True,
         preemph_coeff: float = 0.97,
         window_type: str = "povey",
@@ -465,13 +512,14 @@ class Wav2LogFilterBank(Wav2FFT):
         high_freq: float = -400.0,
         num_filters: int = 80,
         norm_filters: bool = False,
+        torchaudio_compatible_mel_scale: bool = True,
     ):
 
         super().__init__(
             sampling_rate,
             frame_length,
             frame_shift,
-            fft_length,
+            round_to_power_of_two=round_to_power_of_two,
             remove_dc_offset=remove_dc_offset,
             preemph_coeff=preemph_coeff,
             window_type=window_type,
@@ -487,46 +535,54 @@ class Wav2LogFilterBank(Wav2FFT):
         self.high_freq = high_freq
         self.num_filters = num_filters
         self.norm_filters = norm_filters
+        self._eps = nn.Parameter(
+            torch.tensor(torch.finfo(torch.float).eps), requires_grad=False
+        )
 
         if use_fft_mag:
             self._to_spec = _spectrogram
         else:
             self._to_spec = _pow_spectrogram
 
-        fb = create_mel_scale(
-            num_filters=num_filters,
-            fft_length=fft_length,
-            sampling_rate=sampling_rate,
-            low_freq=low_freq,
-            high_freq=high_freq,
-            norm_filters=norm_filters,
-        )
-        self._fb = nn.Parameter(
-            torch.tensor(fb, dtype=torch.get_default_dtype()), requires_grad=False
-        )
+        if torchaudio_compatible_mel_scale:
+            from torchaudio.compliance.kaldi import get_mel_banks
 
-    def forward(self, x):
-        x_strided = self.wav2win(x)
-        if self.use_energy:
-            x_strided, log_e = x_strided
+            # see torchaudio.compliance.kaldi.fbank, lines #581-587 for the original usage
+            fb, _ = get_mel_banks(
+                num_bins=num_filters,
+                window_length_padded=self.fft_length,
+                sample_freq=sampling_rate,
+                low_freq=low_freq,
+                high_freq=high_freq,
+                # VTLN args are hardcoded to torchaudio default values;
+                # they are not used anyway with wapr_factor == 1.0
+                vtln_warp_factor=1.0,
+                vtln_low=100.0,
+                vtln_high=-500.0,
+            )
+            fb = torch.nn.functional.pad(fb, (0, 1), mode="constant", value=0).T
+        else:
+            fb = create_mel_scale(
+                num_filters=num_filters,
+                fft_length=self.fft_length,
+                sampling_rate=sampling_rate,
+                low_freq=low_freq,
+                high_freq=high_freq,
+                norm_filters=norm_filters,
+            )
+        self._fb = nn.Parameter(fb, requires_grad=False)
 
+    def _forward_strided(
+        self, x_strided: torch.Tensor, log_e: Optional[torch.Tensor]
+    ) -> torch.Tensor:
         X = _rfft(x_strided)
         pow_spec = self._to_spec(X)
 
-        try:
-            from torch.cuda.amp import autocast
-        except ImportError:
-            warnings.warn(
-                "Could not import torch.cuda.amp.autocast -- "
-                "when using mixed precision with another package such as apex, "
-                "you might experience numerical stability issues."
-            )
-            pow_spec = torch.matmul(pow_spec.float(), self._fb.float())
-        else:
-            with autocast(enabled=False):
-                pow_spec = torch.matmul(pow_spec.float(), self._fb.float())
-        pow_spec = (pow_spec + 1e-10).log()
-        if self.use_energy:
+        pow_spec = torch.matmul(pow_spec, self._fb)
+        pow_spec = torch.max(pow_spec, self._eps).log()
+
+        # log_e is not None is needed by torchscript
+        if self.use_energy and log_e is not None:
             pow_spec = torch.cat((log_e.unsqueeze(-1), pow_spec), dim=-1)
 
         return pow_spec
@@ -555,7 +611,7 @@ class Wav2MFCC(Wav2FFT):
         sampling_rate: int = 16000,
         frame_length: Seconds = 0.025,
         frame_shift: Seconds = 0.01,
-        fft_length: int = 512,
+        round_to_power_of_two: bool = True,
         remove_dc_offset: bool = True,
         preemph_coeff: float = 0.97,
         window_type: str = "povey",
@@ -571,13 +627,14 @@ class Wav2MFCC(Wav2FFT):
         norm_filters: bool = False,
         num_ceps: int = 13,
         cepstral_lifter: int = 22,
+        torchaudio_compatible_mel_scale: bool = True,
     ):
 
         super().__init__(
             sampling_rate,
             frame_length,
             frame_shift,
-            fft_length,
+            round_to_power_of_two=round_to_power_of_two,
             remove_dc_offset=remove_dc_offset,
             preemph_coeff=preemph_coeff,
             window_type=window_type,
@@ -595,23 +652,43 @@ class Wav2MFCC(Wav2FFT):
         self.norm_filters = norm_filters
         self.num_ceps = num_ceps
         self.cepstral_lifter = cepstral_lifter
+        self._eps = nn.Parameter(
+            torch.tensor(torch.finfo(torch.float).eps), requires_grad=False
+        )
 
         if use_fft_mag:
             self._to_spec = _spectrogram
         else:
             self._to_spec = _pow_spectrogram
 
-        fb = create_mel_scale(
-            num_filters=num_filters,
-            fft_length=fft_length,
-            sampling_rate=sampling_rate,
-            low_freq=low_freq,
-            high_freq=high_freq,
-            norm_filters=norm_filters,
-        )
-        self._fb = nn.Parameter(
-            torch.tensor(fb, dtype=torch.get_default_dtype()), requires_grad=False
-        )
+        if torchaudio_compatible_mel_scale:
+            from torchaudio.compliance.kaldi import get_mel_banks
+
+            # see torchaudio.compliance.kaldi.fbank, lines #581-587 for the original usage
+            fb, _ = get_mel_banks(
+                num_bins=num_filters,
+                window_length_padded=self.fft_length,
+                sample_freq=sampling_rate,
+                low_freq=low_freq,
+                high_freq=high_freq,
+                # VTLN args are hardcoded to torchaudio default values;
+                # they are not used anyway with wapr_factor == 1.0
+                vtln_warp_factor=1.0,
+                vtln_low=100.0,
+                vtln_high=-500.0,
+            )
+            fb = torch.nn.functional.pad(fb, (0, 1), mode="constant", value=0).T
+        else:
+            fb = create_mel_scale(
+                num_filters=num_filters,
+                fft_length=self.fft_length,
+                sampling_rate=sampling_rate,
+                low_freq=low_freq,
+                high_freq=high_freq,
+                norm_filters=norm_filters,
+            )
+        self._fb = nn.Parameter(fb, requires_grad=False)
+
         self._dct = nn.Parameter(
             self.make_dct_matrix(self.num_ceps, self.num_filters), requires_grad=False
         )
@@ -646,40 +723,28 @@ class Wav2MFCC(Wav2FFT):
         dct *= math.sqrt(2.0 / float(num_filters))
         return dct
 
-    def forward(self, x):
-        x_strided = self.wav2win(x)
-        if self.use_energy:
-            x_strided, log_e = x_strided
-
+    def _forward_strided(
+        self, x_strided: torch.Tensor, log_e: Optional[torch.Tensor]
+    ) -> torch.Tensor:
         X = _rfft(x_strided)
         pow_spec = self._to_spec(X)
-
-        try:
-            from torch.cuda.amp import autocast
-        except ImportError:
-            warnings.warn(
-                "Could not import torch.cuda.amp.autocast -- "
-                "when using mixed precision with another package such as apex, "
-                "you might experience numerical stability issues."
-            )
-            pow_spec = torch.matmul(pow_spec.float(), self._fb.float())
-        else:
-            with autocast(enabled=False):
-                pow_spec = torch.matmul(pow_spec.float(), self._fb.float())
-
-        pow_spec = (pow_spec + 1e-10).log()
+        pow_spec = torch.matmul(pow_spec, self._fb)
+        pow_spec = torch.max(pow_spec, self._eps).log()
 
         mfcc = torch.matmul(pow_spec, self._dct)
         if self.cepstral_lifter > 0:
             mfcc *= self._lifter
 
-        if self.use_energy:
+        # log_e is not None is needed by torchscript
+        if self.use_energy and log_e is not None:
             mfcc[:, 0] = log_e
 
         return mfcc
 
 
-def _get_strided_batch(waveform, window_length, window_shift, snip_edges):
+def _get_strided_batch(
+    waveform: torch.Tensor, window_length: int, window_shift: int, snip_edges: bool
+) -> torch.Tensor:
     r"""Given a waveform (2D tensor of size ``(batch_size, num_samples)``,
     it returns a 2D tensor ``(batch_size, num_frames, window_length)``
     representing how the window is shifted along the waveform. Each row is a frame.
@@ -709,8 +774,11 @@ def _get_strided_batch(waveform, window_length, window_shift, snip_edges):
         npad_left = int((window_length - window_shift) // 2)
         npad_right = npad - npad_left
         # waveform = nn.functional.pad(waveform, (npad_left, npad_right), mode='reflect')
-        pad_left = torch.flip(waveform[:, 1 : npad_left + 1], (1,))
-        pad_right = torch.flip(waveform[:, -npad_right - 1 : -1], (1,))
+        pad_left = torch.flip(waveform[:, :npad_left], (1,))
+        if npad_right >= 0:
+            pad_right = torch.flip(waveform[:, -npad_right:], (1,))
+        else:
+            pad_right = torch.zeros(0, dtype=waveform.dtype)
         waveform = torch.cat((pad_left, waveform, pad_right), dim=1)
 
     strides = (
@@ -718,10 +786,86 @@ def _get_strided_batch(waveform, window_length, window_shift, snip_edges):
         window_shift * waveform.stride(1),
         waveform.stride(1),
     )
-    sizes = (batch_size, num_frames, window_length)
+    sizes = [batch_size, num_frames, window_length]
     return waveform.as_strided(sizes, strides)
 
 
+def _get_strided_batch_streaming(
+    waveform: torch.Tensor,
+    window_shift: int,
+    window_length: int,
+    prev_remainder: Optional[torch.Tensor] = None,
+) -> Tuple[torch.Tensor, torch.Tensor]:
+    """
+    A variant of _get_strided_batch that creates short frames of a batch of audio signals
+    in a way suitable for streaming. It accepts a waveform, window size parameters, and
+    an optional buffer of previously unused samples. It returns a pair of waveform windows tensor,
+    and unused part of the waveform to be passed as ``prev_remainder`` in the next call to this
+    function.
+
+    Example usage::
+
+        >>> # get the first buffer of audio and make frames
+        >>> waveform = get_incoming_audio_from_mic()
+        >>> frames, remainder = _get_strided_batch_streaming(
+        ...     waveform,
+        ...     window_shift=160,
+        ...     window_length=200,
+        ... )
+        >>>
+        >>> process(frames)  # do sth with the frames
+        >>>
+        >>> # get the next buffer and use previous remainder to make frames
+        >>> waveform = get_incoming_audio_from_mic()
+        >>> frames, remainder = _get_strided_batch_streaming(
+        ...     waveform,
+        ...     window_shift=160,
+        ...     window_length=200,
+        ...     prev_remainder=prev_remainder,
+        ... )
+
+    .. caution:: This windowing mechanism only supports ``snip_edges=False``.
+
+    :param waveform: A waveform tensor of shape ``(batch_size, num_samples)``.
+    :param window_shift: The shift between frames measured in the number of samples.
+    :param window_length: The number of samples in each window (frame).
+    :param prev_remainder: An optional waveform tensor of shape ``(batch_size, num_samples)``.
+        Can be ``None`` which indicates the start of a recording.
+    :return: a pair of tensors with shapes ``(batch_size, num_frames, window_length)`` and
+        ``(batch_size, remainder_len)``.
+    """
+
+    assert window_shift <= window_length
+    assert waveform.dim() == 2
+    batch_size = waveform.size(0)
+
+    if prev_remainder is None:
+        npad_left = int((window_length - window_shift) // 2)
+        pad_left = torch.flip(waveform[:, :npad_left], (1,))
+        waveform = torch.cat((pad_left, waveform), dim=1)
+    else:
+        assert prev_remainder.dim() == 2
+        assert prev_remainder.size(0) == batch_size
+        waveform = torch.cat((prev_remainder, waveform), dim=1)
+
+    num_samples = waveform.size(-1)
+
+    window_remainder = window_length - window_shift
+    num_frames = (num_samples - window_remainder) // window_shift
+
+    remainder = waveform[:, num_frames * window_shift :]
+
+    strides = (
+        waveform.stride(0),
+        window_shift * waveform.stride(1),
+        waveform.stride(1),
+    )
+
+    sizes = [batch_size, num_frames, window_length]
+
+    return waveform.as_strided(sizes, strides), remainder
+
+
 def _get_log_energy(x: torch.Tensor, energy_floor: float) -> torch.Tensor:
     """
     Returns the log energy of size (m) for a strided_input (m,*)
@@ -730,7 +874,7 @@ def _get_log_energy(x: torch.Tensor, energy_floor: float) -> torch.Tensor:
     if energy_floor > 0.0:
         log_energy = torch.max(
             log_energy,
-            torch.tensor(math.log(energy_floor), dtype=torch.get_default_dtype()),
+            torch.tensor(math.log(energy_floor), dtype=log_energy.dtype),
         )
 
     return log_energy
@@ -743,7 +887,7 @@ def create_mel_scale(
     low_freq: float = 0,
     high_freq: Optional[float] = None,
     norm_filters: bool = True,
-):
+) -> torch.Tensor:
     if high_freq is None or high_freq == 0:
         high_freq = sampling_rate / 2
     if high_freq < 0:
@@ -770,7 +914,7 @@ def create_mel_scale(
     if norm_filters:
         B = B / np.sum(B, axis=0, keepdims=True)
 
-    return B
+    return torch.from_numpy(B)
 
 
 def available_windows() -> List[str]:
@@ -787,13 +931,11 @@ BLACKMAN = "blackman"
 def create_frame_window(window_size, window_type: str = "povey", blackman_coeff=0.42):
     r"""Returns a window function with the given type and size"""
     if window_type == HANNING:
-        return torch.hann_window(window_size, periodic=True)
+        return torch.hann_window(window_size, periodic=False)
     elif window_type == HAMMING:
-        return torch.hamming_window(window_size, periodic=True, alpha=0.54, beta=0.46)
+        return torch.hamming_window(window_size, periodic=False, alpha=0.54, beta=0.46)
     elif window_type == POVEY:
-        a = 2 * math.pi / window_size
-        window_function = torch.arange(window_size, dtype=torch.get_default_dtype())
-        return (0.5 - 0.5 * torch.cos(a * window_function)).pow(0.85)
+        return torch.hann_window(window_size, periodic=False).pow(0.85)
     elif window_type == RECTANGULAR:
         return torch.ones(window_size, dtype=torch.get_default_dtype())
     elif window_type == BLACKMAN:
@@ -814,3 +956,12 @@ def lin2mel(x):
 
 def mel2lin(x):
     return 700 * (np.exp(x / 1127.0) - 1)
+
+
+def next_power_of_2(x: int) -> int:
+    """
+    Returns the smallest power of 2 that is greater than x.
+
+    Original source: TorchAudio (torchaudio/compliance/kaldi.py)
+    """
+    return 1 if x == 0 else 2 ** (x - 1).bit_length()
