@@ -8,10 +8,10 @@ of development set recordings.
 import logging
 import re
 from collections import defaultdict
-from typing import Dict, Iterable, List, Optional, Union
 from pathlib import Path
-import tqdm
+from typing import Dict, Iterable, List, Optional, Union
 
+import tqdm
 from cytoolz import sliding_window
 
 from lhotse import (
@@ -21,12 +21,12 @@ from lhotse import (
     SupervisionSet,
     validate_recordings_and_supervisions,
 )
+from lhotse.manipulation import combine
 from lhotse.qa import (
     remove_missing_recordings_and_supervisions,
     trim_supervisions_to_recordings,
 )
 from lhotse.utils import Pathlike
-from lhotse.manipulation import combine
 
 BABELCODE2LANG = {
     "101": "Cantonese",
@@ -193,9 +193,11 @@ def prepare_single_babel_language(
             output_dir.mkdir(parents=True, exist_ok=True)
             language = BABELCODE2LANG[lang_code]
             save_split = "train" if split == "training" else split
-            recordings.to_file(output_dir / f"recordings_{language}_{save_split}.json")
+            recordings.to_file(
+                output_dir / f"babel-{language}_recordings_{save_split}.jsonl.gz"
+            )
             supervisions.to_file(
-                output_dir / f"supervisions_{language}_{save_split}.json"
+                output_dir / f"babel-{language}_supervisions_{save_split}.jsonl.gz"
             )
 
     return dict(manifests)
